import * as React from "react";
import ServerDataTag from "./ServerDataTag";
declare const ServerDataContext: React.Context<ServerDataStore>;
export { ServerDataContext };
export declare type ActionFunction = (...args: any[]) => Promise<any>;
export interface IAction {
    [index: string]: ActionFunction;
}
export declare class ServerDataStore {
    private static actions;
    private dataLoaders;
    private tagRenderer;
    static isServer: boolean;
    private isFirstRun;
    /** Queues an action to be run either immedietly (client) or after render (server) */
    runAction(name: string, ...args: any[]): void;
    /** Server side version, for client version use the static method
     *  Runs a queued action and returns the result
     */
    getResult(name: string, ...args: any[]): Promise<any>;
    /** Client side version, for server version use the context method
    *   Runs a queued action and returns the result, or fetches from head data if already present
    */
    static getResult(name: string, ...args: any[]): Promise<any>;
    getDataAsString(): Promise<string>;
    getTagsAsString(): Promise<string | undefined>;
    static registerAction(name: string, resolver: ActionFunction): void;
    registerTagRenderer(renderer: ServerDataTag): void;
    readonly firstRun: boolean;
}
